<?php

namespace Drupal\doccheck_basic\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\user\Entity\User;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\doccheck_basic\Plugin\Block\FormBlock;
use Drupal\doccheck_basic\doccheckBasicCommon;

/**
* DocCheck Basic Callback Controller
*/
class CallbackController extends ControllerBase {

    /**
    * {@inheritdoc}
    */
    public function callback_page() {
        \Drupal::service('page_cache_kill_switch')->trigger();

        $config = \Drupal::config('config.doccheck_basic');

        $redirect_page = \Drupal::request()->getSession()->get('dc_page');
        \Drupal::request()->getSession()->remove('dc_page');

        if (strlen($redirect_page) == 0){
            $err_msg = t("No cookie found. DocCheck Basic login cookie error");
            \Drupal::logger('doccheck_basic')->error($err_msg);
            drupal_set_message($err_msg, 'error');
            return [
                '#type' => 'markup',
                '#markup' => '',
                '#cache' => [
                    'max-age' => 0,
                ],
            ];
        }
        if (strlen($config->get('dc_user')) < 1){
            $err_msg = t('DocCheck login user not set');
            \Drupal::logger('doccheck_basic')->error($err_msg);
            drupal_set_message($err_msg, 'error');
            return [
                '#type' => 'markup',
                '#markup' => '',
                '#cache' => [
                    'max-age' => 0,
                ],
            ];
        }
        if (\Drupal::currentUser()->id() == 0){
            $dc_user = \Drupal\user\Entity\User::load($config->get('dc_user'));
            if ($dc_user === false){
                $err_msg = t('DocCheck login username not valid or not selected');
                \Drupal::logger('doccheck_basic')->error($err_msg);
                drupal_set_message($err_msg, 'error');
                return [
                    '#type' => 'markup',
                    '#markup' => '',
                    '#cache' => [
                        'max-age' => 0,
                    ],
                ];
            }
            user_login_finalize($dc_user);

        }

        $response = new RedirectResponse($redirect_page);
        $response->send();
        return $response;
    }

    /**
    * {@inheritdoc}
    */
    public function login_page() {
        return \Drupal\doccheck_basic\doccheckBasicCommon::doccheck_basic_login();
    }
}
