<?php

namespace Drupal\doccheck_basic\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\user\Entity\User;


/**
* Defines a form to configure module settings.
*/
class SettingsForm extends ConfigFormBase {
    public function __construct(ConfigFactoryInterface $config_factory) {

        parent::__construct($config_factory);
    }

    /**
    * {@inheritdoc}
    */
    public function getFormID() {
        return 'doccheck_basic.settings';
    }

    /**
    * {@inheritdoc}
    */
    protected function getEditableConfigNames() {
        return ['config.doccheck_basic'];
    }

    /**
    * {@inheritdoc}
    */
    public function buildForm(array $form, FormStateInterface $form_state) {

        $config = \Drupal::config('config.doccheck_basic');
        $form['doccheck_cream'] = [
            '#type' => 'fieldset',
            '#title' => 'Settings at DocCheck CReaM',
            '#collapsible' => TRUE,
            '#collapsed' => FALSE,
        ];

        $form['doccheck_cream']['targetlink'] = [
            '#type' => 'item',
            '#title' => t('Target URL, copy to DocCheck CReaM (crm.doccheck.com)'),
            '#description' => \Drupal::request()->getSchemeAndHttpHost() . '/_dc_callback',
        ];


        $form['doccheck_basic'] = [
            '#type' => 'fieldset',
            '#title' => 'Settings for local site',
            '#collapsible' => TRUE,
            '#collapsed' => FALSE,
        ];

        $form['doccheck_basic']['devmode'] = [
            '#type' => 'checkbox',
            '#title' => t('Development mode'),
            '#default_value' =>
            $config->get('dc_devmode') ? $config->get('dc_devmode') :
            false,
            '#description' =>  t('Show direct login button for development, before Doccheck account is set up.') ,
        ];
        $form['doccheck_basic']['template'] = [
            '#type' => 'select',
            '#title' => t('Template'),
            '#default_value' => $config->get('dc_template') ? $config->get('dc_template') : 'L',
            '#options' => [
                's_red' => 'S',
                'm_red' => 'M',
                'l_red' => 'L',
                'xl_red' => 'XL',
            ],
            '#description' =>  t('Template for DocCheck login frame') ,
            '#required' => TRUE,
        ];
        $form['doccheck_basic']['loginid'] = [
            '#type' => 'textfield',
            '#title' => t('DocCheck Login ID'),
            '#description' => t('Login ID from DocCheck CReaM'),
            '#default_value' => $config->get('dc_loginid') ? $config->get('dc_loginid') : '12345678901234567890',
            '#size' => 13,
            '#required' => TRUE,
        ];

        $filtered_users = [];
        $all_users = \Drupal\user\Entity\User::loadMultiple();
        foreach ($all_users as $key => $value) {
            if (!$value->hasRole('anonymous') && !$value->hasRole('administrator')){
                $filtered_users[$key] = $value->getDisplayName();
            }
        }
        $form['doccheck_basic']['user'] = [
            '#type' => 'select',
            '#title' => t('Login as User'),
            '#description' => t('Please ensure that the user has no admin rights! Administrator and Anonymous user roles are excluded. Please ensure that the user has view rights for the protected pages.'),
            '#default_value' => $config->get('dc_user') ? $config->get('dc_user') : '',
            '#required' => TRUE,
            '#options' => $filtered_users,
        ];
        return parent::buildForm($form, $form_state);
    }

    /**
    * {@inheritdoc}
    */
    public function validateForm(array &$form, FormStateInterface $form_state) {
        parent::validateForm($form, $form_state);
    }

    /**
    * {@inheritdoc}
    */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        $config = \Drupal::configFactory()->getEditable('config.doccheck_basic');

        $config->set('dc_devmode', $form_state->getValue('devmode'));
        $config->set('dc_template', $form_state->getValue('template'));
        $config->set('dc_loginid', $form_state->getValue('loginid'));
        $config->set('dc_user', $form_state->getValue('user'));

        $config->save();

        return parent::submitForm($form, $form_state);
    }

}
